@@ -3,7 +3,7 @@
 
    Load, manipulate and display images
 
-   Copyright (C) 1996, 2005 Free Software Foundation, Inc.
+   Copyright (C) 1996-2016 Free Software Foundation, Inc.
 
    Written by:  Adam Fedor <fedor@colorado.edu>
    Date: Feb 1996
@@ -31,9 +31,9 @@
 #define _GNUstep_H_NSImage
 #import <GNUstepBase/GSVersionMacros.h>
 
-#include <AppKit/NSGraphicsContext.h>
-#include <Foundation/NSBundle.h>
-#include <AppKit/NSBitmapImageRep.h>
+#import <AppKit/NSGraphicsContext.h>
+#import <Foundation/NSBundle.h>
+#import <AppKit/NSBitmapImageRep.h>
 
 @class NSString;
 @class NSMutableArray;
@@ -45,6 +45,24 @@
 @class NSColor;
 @class NSView;
 
+/* Named images */
+
+APPKIT_EXPORT NSString *NSImageNameMultipleDocuments;
+
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_5, GS_API_LATEST)
+APPKIT_EXPORT NSString *NSImageNameUserAccounts;
+APPKIT_EXPORT NSString *NSImageNamePreferencesGeneral;
+APPKIT_EXPORT NSString *NSImageNameAdvanced;
+APPKIT_EXPORT NSString *NSImageNameInfo;
+APPKIT_EXPORT NSString *NSImageNameFontPanel;
+APPKIT_EXPORT NSString *NSImageNameColorPanel;
+#endif
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_6, GS_API_LATEST)
+APPKIT_EXPORT NSString *NSImageNameTrashEmpty;
+APPKIT_EXPORT NSString *NSImageNameTrashFull;
+APPKIT_EXPORT NSString *NSImageNameCaution;
+#endif
+
 /** Defines how an NSImage is to be cached.  Possible values are:
  *  <list>
  *   <item>NSImageCacheDefault</item>
@@ -240,19 +258,19 @@ typedef enum {
 		 fromRect: (NSRect)aRect
 		operation: (NSCompositingOperation)op;
 - (void) dissolveToPoint: (NSPoint)aPoint
-		fraction: (float)aFloat;
+		fraction: (CGFloat)aFloat;
 - (void) dissolveToPoint: (NSPoint)aPoint
 		fromRect: (NSRect)aRect
-		fraction: (float)aFloat;
+		fraction: (CGFloat)aFloat;
 
 #if OS_API_VERSION(GS_API_MACOSX, GS_API_LATEST)
 - (void) compositeToPoint: (NSPoint)aPoint
 		 fromRect: (NSRect)srcRect
 		operation: (NSCompositingOperation)op
-		 fraction: (float)delta;
+		 fraction: (CGFloat)delta;
 - (void) compositeToPoint: (NSPoint)aPoint
 		operation: (NSCompositingOperation)op
-		 fraction: (float)delta;
+		 fraction: (CGFloat)delta;
 #endif 
 
 //
@@ -284,6 +302,17 @@ typedef enum {
  *  place and finds the best representation.
  */
 - (NSImageRep*) bestRepresentationForDevice: (NSDictionary*)deviceDescription;
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_6, GS_API_LATEST)
+/**
+ * Finds the best representation for drawing in the specified rect.
+ * 
+ * context and hints are currently ignored.
+ */
+- (NSImageRep *)bestRepresentationForRect: (NSRect)rect
+				  context: (NSGraphicsContext *)context
+				    hints: (NSDictionary *)hints;
+#endif
+
 - (NSArray*) representations;
 
 /** Remove the NSImageRep imageRep from the NSImage's representations 
@@ -321,7 +350,7 @@ typedef enum {
 - (void) drawAtPoint: (NSPoint)point
 	    fromRect: (NSRect)srcRect
 	   operation: (NSCompositingOperation)op
-	    fraction: (float)delta;
+	    fraction: (CGFloat)delta;
 
 /** <p>Takes the part of the receiver given by <code>srcRect</code> and
  *  draws it in <code>dstRect</code> in the current coordinate system,
@@ -339,9 +368,30 @@ typedef enum {
 - (void) drawInRect: (NSRect)dstRect
 	   fromRect: (NSRect)srcRect
 	  operation: (NSCompositingOperation)op
-	   fraction: (float)delta;
+	   fraction: (CGFloat)delta;
 #endif 
 
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_6, GS_API_LATEST)
+
+- (void) drawInRect: (NSRect)dstRect
+	   fromRect: (NSRect)srcRect
+	  operation: (NSCompositingOperation)op
+	   fraction: (CGFloat)delta
+     respectFlipped: (BOOL)respectFlipped
+	      hints: (NSDictionary*)hints;
+
+#endif
+
+/**
+ * <p>Draws the entire image in <code>rect</code> scaling if needed.<br>
+ * Drawing is done using <code>NSCompositeSourceOver</code>.
+ * </p>
+ */
+
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_6, GS_API_LATEST)
+- (void) drawInRect: (NSRect)rect;
+#endif
+
 //
 // Determining How the Image is Drawn 
 //
