@@ -68,6 +68,28 @@ typedef enum _NSTableViewColumnAutoresizingStyle
 } NSTableViewColumnAutoresizingStyle;
 #endif
 
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_5, GS_API_LATEST)
+typedef enum _NSTableViewSelectionHighlightStyle
+{
+  NSTableViewSelectionHighlightStyleNone = -1,
+  NSTableViewSelectionHighlightStyleRegular = 0,
+  NSTableViewSelectionHighlightStyleSourceList = 1
+} NSTableViewSelectionHighlightStyle;
+#endif
+
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_7, GS_API_LATEST)
+typedef enum _NSTableViewAnimationOptions
+{
+  NSTableViewAnimationEffectNone = 0x0,
+  NSTableViewAnimationEffectFade = 0x1,
+  NSTableViewAnimationEffectGap  = 0x2,
+  NSTableViewAnimationSlideUp    = 0x10,
+  NSTableViewAnimationSlideDown  = 0x20,
+  NSTableViewAnimationSlideLeft  = 0x30,
+  NSTableViewAnimationSlideRight = 0x40,
+} NSTableViewAnimationOptions;
+#endif
+
 
 @interface NSTableView : NSControl <NSUserInterfaceValidations>
 {
@@ -79,6 +101,7 @@ typedef enum _NSTableViewColumnAutoresizingStyle
   BOOL               _drawsGrid;
   NSColor           *_gridColor;
   NSColor           *_backgroundColor;
+  NSTableViewSelectionHighlightStyle _selectionHighlightStyle;
   float              _rowHeight;
   NSSize             _intercellSpacing;
   id                 _delegate;
@@ -148,6 +171,8 @@ typedef enum _NSTableViewColumnAutoresizingStyle
 
   NSDragOperation _draggingSourceOperationMaskForLocal;
   NSDragOperation _draggingSourceOperationMaskForRemote;
+
+  NSInteger _beginEndUpdates;
 }
 
 /* Data Source */
@@ -186,6 +211,10 @@ typedef enum _NSTableViewColumnAutoresizingStyle
 - (void) setUsesAlternatingRowBackgroundColors: (BOOL)useAlternatingRowColors;
 - (BOOL) usesAlternatingRowBackgroundColors;
 #endif
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_5, GS_API_LATEST)
+- (void)setSelectionHighlightStyle: (NSTableViewSelectionHighlightStyle)s;
+- (NSTableViewSelectionHighlightStyle) selectionHighlightStyle;
+#endif
 
 /* Columns */
 - (void) addTableColumn: (NSTableColumn *)aColumn;
@@ -339,6 +368,19 @@ typedef enum _NSTableViewColumnAutoresizingStyle
 - (NSArray *) sortDescriptors;
 #endif
 
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_6, GS_API_LATEST)
+- (void) reloadDataForRowIndexes: (NSIndexSet*)rowIndexes columnIndexes: (NSIndexSet*)columnIndexes;
+#endif
+
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_7, GS_API_LATEST)
+- (void) beginUpdates;
+- (void) endUpdates;
+- (NSInteger) columnForView: (NSView*)view;
+- (void) insertRowsAtIndexes: (NSIndexSet*)indexes withAnimation: (NSTableViewAnimationOptions)animationOptions;
+- (void) removeRowsAtIndexes: (NSIndexSet*)indexes withAnimation: (NSTableViewAnimationOptions)animationOptions;
+- (NSInteger) rowForView: (NSView*)view;
+#endif
+
 @end /* interface of NSTableView */
 
 @interface NSTableView (GNUPrivate)
@@ -351,7 +393,13 @@ typedef enum _NSTableViewColumnAutoresizingStyle
  * Informal protocol NSTableDataSource 
  */
 
+@protocol NSTableViewDataSource
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_6, GS_API_LATEST) && GS_PROTOCOLS_HAVE_OPTIONAL
+@optional
+#else
+@end
 @interface NSObject (NSTableDataSource)
+#endif
 
 /**
  * Returns the number of records that the data source manages for <em>aTableView</em>.
@@ -402,8 +450,13 @@ APPKIT_EXPORT NSString *NSTableViewSelectionIsChangingNotification;
  * Methods Implemented by the Delegate
  */
 
+@protocol NSTableViewDelegate <NSObject>
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_6, GS_API_LATEST) && GS_PROTOCOLS_HAVE_OPTIONAL
+@optional
+#else
+@end
 @interface NSObject (NSTableViewDelegate)
-
+#endif
 - (BOOL) selectionShouldChangeInTableView: (NSTableView *)aTableView;
 #if OS_API_VERSION(MAC_OS_X_VERSION_10_3, GS_API_LATEST)
 - (void) tableView: (NSTableView*)tableView
